summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_calcer.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_calcer.cc')
-rw-r--r--kig/objects/object_calcer.cc30
1 files changed, 15 insertions, 15 deletions
diff --git a/kig/objects/object_calcer.cc b/kig/objects/object_calcer.cc
index f6952768..0bf4e774 100644
--- a/kig/objects/object_calcer.cc
+++ b/kig/objects/object_calcer.cc
@@ -131,21 +131,21 @@ const ObjectType* ObjectTypeCalcer::type() const
return mtype;
}
-ObjectPropertyCalcer::ObjectPropertyCalcer( ObjectCalcer* tqparent, int propid )
- : mimp( 0 ), mtqparent( tqparent ), mpropid( propid )
+ObjectPropertyCalcer::ObjectPropertyCalcer( ObjectCalcer* parent, int propid )
+ : mimp( 0 ), mparent( parent ), mpropid( propid )
{
// Some weird C++ thing prevents me from calling protected members
- // of ObjectCalcer on mtqparent.. This is an ugly workaround..
- ( mtqparent->*&ObjectCalcer::addChild )( this );
- //mtqparent->addChild( this );
+ // of ObjectCalcer on mparent.. This is an ugly workaround..
+ ( mparent->*&ObjectCalcer::addChild )( this );
+ //mparent->addChild( this );
}
ObjectPropertyCalcer::~ObjectPropertyCalcer()
{
// Some weird C++ thing prevents me from calling protected members
- // of ObjectCalcer on mtqparent.. This is an ugly workaround..
- ( mtqparent->*&ObjectCalcer::delChild )( this );
- //mtqparent->delChild( this );
+ // of ObjectCalcer on mparent.. This is an ugly workaround..
+ ( mparent->*&ObjectCalcer::delChild )( this );
+ //mparent->delChild( this );
delete mimp;
}
@@ -157,13 +157,13 @@ const ObjectImp* ObjectPropertyCalcer::imp() const
std::vector<ObjectCalcer*> ObjectPropertyCalcer::parents() const
{
std::vector<ObjectCalcer*> ret;
- ret.push_back( mtqparent );
+ ret.push_back( mparent );
return ret;
}
void ObjectPropertyCalcer::calc( const KigDocument& doc )
{
- ObjectImp* n = mtqparent->imp()->property( mpropid, doc );
+ ObjectImp* n = mparent->imp()->property( mpropid, doc );
delete mimp;
mimp = n;
}
@@ -183,7 +183,7 @@ std::vector<ObjectCalcer*> ObjectCalcer::tqchildren() const
const ObjectImpType* ObjectPropertyCalcer::impRequirement(
ObjectCalcer*, const std::vector<ObjectCalcer*>& ) const
{
- return mtqparent->imp()->impRequirementForProperty( mpropid );
+ return mparent->imp()->impRequirementForProperty( mpropid );
}
const ObjectImpType* ObjectConstCalcer::impRequirement(
@@ -276,9 +276,9 @@ void ObjectTypeCalcer::move( const Coordinate& to, const KigDocument& doc )
mtype->move( *this, to, doc );
}
-ObjectCalcer* ObjectPropertyCalcer::tqparent() const
+ObjectCalcer* ObjectPropertyCalcer::parent() const
{
- return mtqparent;
+ return mparent;
}
ObjectCalcer::ObjectCalcer()
@@ -303,8 +303,8 @@ bool ObjectConstCalcer::isDefinedOnOrThrough( const ObjectCalcer* ) const
bool ObjectPropertyCalcer::isDefinedOnOrThrough( const ObjectCalcer* o ) const
{
- return o == mtqparent &&
- mtqparent->imp()->isPropertyDefinedOnOrThroughThisImp( propId() );
+ return o == mparent &&
+ mparent->imp()->isPropertyDefinedOnOrThroughThisImp( propId() );
}
bool ObjectTypeCalcer::isDefinedOnOrThrough( const ObjectCalcer* o ) const